@@ -104,7 +104,9 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
                     if found_response.packages.is_empty() {
                         println!("{}", style("No packages found").bold().yellow());
                     } else {
-                        for package in found_response.packages {
+                        let packages = found_response.packages;
+                        let num_packages = packages.len();
+                        for (i, package) in packages.into_iter().enumerate() {
                             println!(
                                 "{} -> {}",
                                 style(package.name).green(),
@@ -115,7 +117,9 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
                                 )
                             );
                             println!("{}", style(package.url).dim());
-                            println!("");
+                            if (i + 1) < num_packages {
+                                println!("");
+                            }
                         }
                     }
                 }
